#[non_exhaustive]#[repr(i32)]pub enum MetadataCapState {
Unknown = 0,
Claimed = 1,
Unclaimed = 2,
Deleted = 3,
}Expand description
Information about the state of the coin’s MetadataCap
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unknown = 0
Indicates the state of the MetadataCap is unknown. Set when the coin has not been migrated to the CoinRegistry.
Claimed = 1
Indicates the MetadataCap has been claimed.
Unclaimed = 2
Indicates the MetadataCap has not been claimed.
Deleted = 3
Indicates the MetadataCap has been deleted.
Implementations
Sourceimpl MetadataCapState
impl MetadataCapState
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of MetadataCapState.
Sourcepub fn from_i32(value: i32) -> Option<MetadataCapState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<MetadataCapState>
Use the TryFrom<i32> implementation instead
Converts an i32 to a MetadataCapState, or None if value is not a valid variant.
Sourceimpl MetadataCapState
impl MetadataCapState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.